@@ -1,5 +1,5 @@
 # This file is part of LTSP, https://ltsp.org
-# Copyright 2020 the LTSP team, see AUTHORS
+# Copyright 2020-2022 the LTSP team, see AUTHORS
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # If the root file system is read-only, it means that `ltsp initrd-bottom`
@@ -27,7 +27,7 @@ ro_root_main() {
         # We want an existing mount point for the tmpfs outside of /run,
         # otherwise switch_root can't move the /run mount as it's in use.
         # Let's use /root that is used by initramfs-tools and always exists.
-        re vmount -t nfs -o vers=3,nolock "$SERVER:/srv/ltsp" /root
+        re vmount -t nfs -o vers=3,nolock "$SERVER:$BASE_DIR" /root
         re vmount -o loop,ro "/root/$IMAGE" /root
         re mount_img_src /root /root /run/initramfs/ltsp
     else
@@ -43,7 +43,7 @@ ro_root_main() {
 fetch_ltsp_img() {
     re mkdir -p /run/ltsp/tmp/tftp
     re vmount --no-exit -t nfs -o vers=3,tcp,nolock \
-        "$SERVER:/srv/tftp/ltsp" /run/ltsp/tmp/tftp
+        "$SERVER:${TFTP_DIR}/ltsp" /run/ltsp/tmp/tftp
     re test -f /run/ltsp/tmp/tftp/ltsp.img
     re mkdir -p /run/ltsp/tmp/ltsp-img
     (
@@ -61,16 +61,8 @@ install_ltsp() {
 
     src=$1
     dst=$2
-    if is_command rsync; then
-        re rsync -a --delete "$src/usr/share/ltsp/" "$dst/usr/share/ltsp"
-        re rsync -a --delete "$src/etc/ltsp/" "$dst/etc/ltsp"
-    else
-        re rm -rf "$dst/usr/share/ltsp"
-        re cp -a "$src/usr/share/ltsp" "$dst/usr/share/"
-        re rm -rf "$dst/etc/ltsp"
-        re cp -a "$src/etc/ltsp" "$dst/etc/"
-    fi
-    ls -lha "$dst/usr/share/ltsp"
+    re cp -au "$src/usr/share/ltsp" "$dst/usr/share/"
+    re cp -au "$src/etc/ltsp" "$dst/etc/"
     # Symlink the ltsp binary
     re ln -sf ../share/ltsp/ltsp "$dst/usr/sbin/ltsp"
     # Symlink the service; use absolute symlink due to /usr/lib migration
