@@ -1,11 +1,9 @@
 # This file is part of LTSP, https://ltsp.org
-# Copyright 2019 the LTSP team, see AUTHORS
+# Copyright 2019-2020 the LTSP team, see AUTHORS
 # SPDX-License-Identifier: GPL-3.0-or-later
 
 # Configure systemd related things
 systemd_main() {
-    local var
-
     # Use loglevel from /proc/cmdline instead of resetting it
     # Remember, `false && false` doesn't exit; use `||` when not using re/rw
     grep -qsw netconsole /proc/cmdline &&
@@ -26,11 +24,4 @@ systemd_main() {
     test -f "/etc/systemd/user.conf" &&
         rw sed "s|[^[alpha]]*DefaultTimeoutStopSec=.*|DefaultTimeoutStopSec=10s|" \
             -i "/etc/systemd/user.conf"
-    # Mask services
-    for var in apt-daily.service apt-daily-upgrade.service \
-        snapd.seeded.service rsyslog.service
-    do
-        rw ln -s /dev/null "/etc/systemd/system/$var"
-    done
-    # TODO: or this; both are fast: rw systemctl mask --quiet --root=/ --no-reload apt-daily.service apt-daily-upgrade.service snapd.seeded.service rsyslog.service
 }
